---
permalink: what-does-rackspace-do-in-the-cloud
audit_date: '2019-01-23'
title: What does Rackspace do in the cloud?
type: article
created_date: '2019-02-04'
created_by: Rackspace Community
last_modified_date: '2019-02-04'
last_modified_by: Kate Dougherty
product: Cloud Servers
product_url: cloud-servers
---

Managed Cloud customers can choose from three service levels. You can see a
[high-level comparison of these service
levels](https://www.rackspace.com/openstack/public/service-levels) on our
website. But what do these service levels really mean for you? This article
briefly describes each service level in more detail.

### Managed Infrastructure service level

This section describes the Managed Infrastructure service level.

#### Technical support

The Managed Infrastructure service level gives you 24x7x365 access to our Cloud
Engineers. You can communicate with these experts by chat, phone, or by
creating a ticket. These engineers can provide guidance, but they do not have
access to log in to your servers directly. If you experience an issue with
your server or web site, they can help you.

#### Architecture advice

This service level also provides access to cloud architecture advisors. For
example, if you expect an increase in traffic, they can provide advice
regarding how to set up your environment.

#### Launch assistance

You have access to launch assistance for the first 60 days. During this
period, you can reach out to your Launch Manager directly to ask questions
ranging from "How do I set up a new user for the Control Panel?" to "How
should I configure my environment?"

#### Security guidance

Cloud engineers are also available to provide security guidance. While they
cannot log in to your servers to make changes, they can suggest ways to make
your server more secure, such as using firewall rules to lock down access to
the server.

#### Development help

Finally, you also have access to code development assistance. If your code
leverages our API interfaces, we can help you ensure that it is accessing them
correctly. We cannot adjust your code, but we can help you troubleshoot any
API errors that you might encounter.

### Managed SysOps service level

The Managed SysOps service level includes the basic pillars of support that
Managed Infrastructure does, and also provides additional services.

#### Technical support

Similar to the Managed Infrastructure service level, you have access to our
Cloud Engineers. However, at the Managed SysOps level, they are able to access
your servers. If you experience an issue with your server or website, they are
able to log in to the machine and help pinpoint the cause. If the cause is
code-related, your developer will know where to go to resolve it.

#### Architecture advice

At the Managed SysOps service level, a dedicated Technical Account Manager
is assigned to your account. This person works with you to ensure your
success. For example, if you aware of an upcoming event that will drive an
unusually high amount of traffic to your site, your Technical Account Manager
can provide guidance about how to configure your environment.

#### Development help

This service level offers code development assistance. If your code leverages
our API interfaces, we help you ensure that it is accessing them correctly.
Similar to the Managed Infrastructure service level, we cannot adjust your
code. However, we can log in to the server, review what you are doing, and test
accessing the interfaces from your server to ensure that there aren't any
issues with access. These checks help determine whether an issue is
code-related. If so, your developer will know how to address the issue.

#### Backups

At this service level, we preinstall Cloud Backup on your servers and
configure weekly backups of your standard system configuration files. (File
storage fees apply). We also restore, monitor, and troubleshoot backup jobs.
If you have additional files or folders beyond the standard ones that you want
to back up, we can also assist with creating new backup jobs.

#### Other support

Rackspace configures, monitors, and troubleshoots common services for you. We
keep your server up to date with the latest patches and firmware updates,
which we configure to run automatically.

We can install and configure common web servers, app servers, databases, and
language frameworks for Linux&reg; and Windows&reg;. For Linux this includes
(but is not limited to) the following technologies:

- Apache&reg;
- MySQL&reg;
- PHP&reg;

For Windows this includes (but is not limited to) the following technologies:

- Internet Information Services (IIS) 7.5 and 8.0
- Microsoft&reg; SQL Server&reg;
- ASP.NET

We can configure the servers to serve website content and assist with
troubleshooting if the site experiences issues.

We can also configure monitoring alerts for your needs, and
respond to any alarm conditions 24x7x365. If an alarm triggers at 2 AM on a
Saturday morning, our Cloud Engineers will find a resolution.

Your Account Manager is your first point of contact for any account-related
questions, billing questions, Control Panel questions, or account guidance.

### DevOps Automation service level

At the DevOps Automation service level, you receive all of the same services
that are available at the Managed SysOps service level, but with some
additional features.

#### Configuration management

We provide configuration management services at this level.
Configuration management enables you to scale horizontally, without a manual
setup. We can take your existing infrastructure (development, staging, and
production) and automate it by using Chef&trade; or Microsoft&reg; Desired
State Configuration (CSC). These services enable you to deploy new features
to market faster.

This service level gives you Chef cookbook management. We create, modify, and
maintain your cookbooks, without taking access away from you. You still have
access to the code that powers and automates your infrastructure. We'll be
here to assist you when you need us.

Configuration management also gives you on-demand scaling, which helps you
accommodate planned and unplanned events that drive a high amount of traffic
to your site or application. With on-demand scaling, you can scale your
environment quickly to handle these situations.

#### Performance monitoring

At the DevOps automation service level, we monitor your performance metrics by
using tools like New Relic&reg;, Cloud Monitoring, and StatsD and Graphite.
Monitoring helps us understand how your performance changes in response to
code changes and other events. These tools enable us to provide a faster
response time if the code needs to be rolled back or modified.

We can also track critical business metrics such as credit card processing
times and signups. Monitoring these metrics helps you pinpoint any slowness
that your customers might be experiencing.

We aggregate logs from all your devices and present them to you through the
Kibana&reg; web interface. We can spot anomalies and patterns in product usage
by simplifying analytics for millions of lines of logs. We drill down into
these detailed logs to explain performance trends.

#### Technical support

You have 24x7x365 access to our DevOps Engineers by phone, chat, and support
ticket. These experts have scaled some of the busiest and most complex web
applications in the world. They are always available to help answer any
questions that you have or make adjustments to your configurations.

You also have access to a private GitHub repository, which gives you full
visibility into all of the code that powers your infrastructure. Our DevOps
Engineers collaborate with you to make changes and document every change.

In addition to monitoring results and log analytics, we can review any issues
that stem from any of these changes. Because GitHub tracks every change, we
are always able to roll changes back quickly to get you to a stable state.

### Conclusion

This article presents a brief comparison of the differences between Rackspace
cloud service levels. Each service level has additional, smaller differences.
No service level is necessarily better than another. Choose the service level
that's best for your own business needs.
