---
permalink: manage-cloud-office-administrator-information-in-the-control-panel
audit_date: '2020-11-03'
title: Manage Cloud Office Administrator information in the Control Panel
type: article
created_date: '2020-10-23'
created_by: Nicholas Ramirez
last_modified_date: '2022-12-22'
last_modified_by: Chris Phillips
product: Rackspace Email
product_url: rackspace-email
---


### Prerequisites 

- **Applies to:** Administrator
- **Difficulty:** Easy
- **Time needed:** 5-10 Minutes
- **Tools required:** Rackspace Cloud Office Administrator credentials

For more information about prerequisite terminology, see [Cloud Office support terminology](https://docs.rackspace.com/support/how-to/cloud-office-support-terminology/).

This article describes how to modify information for your Cloud Office Control Panel Administrator by using the **My Profile** feature in
the [Cloud Office Control Panel](https://cp.rackspace.com/).

**IMPORTANT:** Managed and Dedicated customers access contacts and permissions in the MyRackspace Portal. For more information, see
[Adding or Editing Users](https://docs.rackspace.com/docs/portal-onboarding-guide/administrative/access_permissions_users/) in the MyRackspace Portal.


### Access *My Account* in the Cloud Office Control Panel

If you, as a Cloud Office Administrator, want to update your own contact information, security settings, authentication methods, or notification preferences,
you can do this in the **My Account** section of the [Cloud Office Control Panel](https://cp.rackspace.com/).

Use the following steps to access the **My Profile** section of the [Cloud Office Control Panel](https://cp.rackspace.com/):

1. Log in to the [Cloud Office Control Panel](https://cp.rackspace.com/) by using your Cloud Office administrator credentials.

2. Click the **My Account** in the top-right hand corner and then click **Administrators** from the drop-down menu.


Use the steps in the following sections to make changes to your account and security settings.


#### Cloud Office Control Panel admin information

Use the following steps to modify your **Admin Information** in the **My Account** section of the [Cloud Office Control Panel](https://cp.rackspace.com/):

1. Click the **Manage** button next to the Adminstrator and then choose one of the following fields to update:

   - **First Name**
   - **Last Name**
   - **Email Address**
   - **Contact Phone Number**
   - **Job Title**

2. After you finish modifying your admin information, click **Update Admin Information** to save your changes.


**Note:** We recommend using an email address that is _not_ hosted under the same account.


#### Security question and answer

Use the following steps to modify your **Security Question and Answer** from within the **My Profile** section of the [Cloud Office Control Panel](https://cp.rackspace.com/):

1. Click **Edit Security Question**.

2. Select a **Security Questions** from the list available within the drop-down menu, then enter your **Security Answer** in the field provided.

3. Click **Update Security Question** to save your changes.


**Note:** To receive phone or chat support, Cloud Office Administrators must have a valid security question and answer configured.


#### Multi-Factor authentication methods


Cloud Office Administrators must set up a **Multi-Factor Authentication Method** as a second layer of security for their account. Administrators
can choose between SMS text delivery for verification or a mobile authenticator application for verification.

Use the following steps to modify your **Multi-Factor Authentication** settings within the **My Profile** section of the [Cloud Office Control Panel](https://cp.rackspace.com/):


**Edit your current primary phone number for login verification:**

1. Click **Edit Multi-Factor Authentication**.

2. Enter your updated **Primary Number** within the field provided, then select **Update Multi-Factor Authentication**.

3. Enter the six-digit verification code sent to your mobile device within the field provided, then click **Verify Phone** to save your changes.


**Configure a back-up number:**

1. Click **Edit Multi-Factor Authentication**.

2. Click **Add Backup Number**.

3. Enter your **Backup Number** in the field provided, then click **Update Multi-Factor Authentication** to save your changes.


**Switch your multi-factor authentication method from SMS text message delivery to mobile app delivery:**

1. Click the **Arrow** next to **Edit Multi-Factor Authentication**, then click **Switch to mobile app delivery**.

2. Follow the prompts within the **Securing Your Admin Account with an Authenticator App** window, then click **Verify Code** to save your changes.


**Set up a mobile authenticator app on a new mobile device:**

1. Click the **Arrow** next to **Edit Multi-Factor Authentication**, then click **Setup on new mobile device**.

2. Follow the prompts within the **Securing Your Admin Account with an Authenticator App** window, then click **Verify Code** to save your changes.


**Note:** For more in-depth set-up instructions regarding mobile authenticator apps, please refer to our [Multi-Factor Authentication Mobile App](https://docs.rackspace.com/support/how-to/set-up-multifactor-authentification-applications-for-cloud-office/) guide.


**Switch your multi-factor authentication method from mobile app delivery to SMS text message delivery:**

1. Click the **Arrow** next to **Edit Multi-Factor Authentication**, then click **Switch to SMS Text Message Delivery**.

2. Enter your **Phone Number** into the field provided, then click **Next** to send a six-digit verification code to your mobile device.

3. Enter the six-digit code within the field provided, then click **Verify Phone** to save your changes.


#### Trusted devices


*Trusted devices* allow a Cloud Office administrator to log in from specified devices without being prompted for multi-factor authentication on each login attempt. Adminstrators can establish trusted devices when they log in from a new device by opting to **Remember This Device** during the initial sign-in process.

Use the following steps to modify your **Trusted Devices** within the **My Profile** section of the [Cloud Office Control Panel](https://cp.rackspace.com/):


**Remove trusted devices:**

1. Click **Edit Trusted Devices**.

2. Click on the **Trash** icon for the **Trusted Device** that you want to remove.

3. Click **Update Trusted Devices** to save your changes.


**Note:** Trusted devices are remembered for 30 days, and each successful login from a trusted device resets the expiration period back to 30 days.


#### Notification settings


**Notification Settings** allow a Cloud Office Administrator to choose what types of alerts they want to receive regarding billing information, product updates, and system alerts.

Use the following steps to modify your **Notification Settings** within the **My Profile** section of the [Cloud Office Control Panel](https://cp.rackspace.com/):


1. Click **Edit Notification Settings**, then select one or more of the following options:

   - **Billing Information**
   - **Product and Service Updates**
   - **System Alerts**

2. Click **Update Notifications** to save your changes.


#### Security settings


**Security Settings** allow a Cloud Office Administrator to set up optional password expiration periods as well as allowing the administrator to restrict log-in attempts to specific IP addresses.

Use the following steps to modify your **Security Settings** within the **My Profile** section of the [Cloud Office Control Panel](https://cp.rackspace.com/):


**Create a password expiration policy:**

1. Click **Edit Security Settings**.

2. **Check** the box next to **Password Expires in**, and enter your desired value within the field provided.

3. Click **Update Security Settings** to save your changes.


**Restrict login access to specific IP addresses:**

1. Click **Edit Security Settings**.

2. **Check** the box next to **Login restricted to IP address(es)**, and enter up to three IP addresses within the field provided.

3. Click **Update Security Settings** to save your changes.


#### Linked accounts


*Linked accounts* allow a Cloud Office Administrator to seamlessly transition between the [Cloud Office Control Panel](https://cp.rackspace.com/) and the [Office 365 Control Panel](https://manage365.rackspace.com/).

Use the following steps to modify your **Linked Accounts** within the **My Profile** section of the [Cloud Office Control Panel](https://cp.rackspace.com/):


**Link a Microsoft 365 admin ID:**

1. Navigate to the [Microsoft 365 section of the Cloud Office Control Panel](https://cp.rackspace.com/Office365/).

2. Click **Sign In With Your Microsoft Admin Account**.

3. **Sign In** by using your **Microsoft 365 Admin Credentials** when prompted to link your account successfully.


**Unlink accounts:**

1. Click **Unlink Account** within the **Linked Accounts** section of **My Profile**.

2. Click **Unlink Account** once again when prompted to save your changes.


**Note:** Unlinking an account requires you to be signed-in to both your Cloud Office Control Panel administrator as well as your Microsoft 365 Administrator.


For more information regarding the management of other Cloud Office Administrators within your account, reference our [Email Administrator Management Documentation](https://docs.rackspace.com/support/how-to/manage-email-administrators-with-the-cloud-office-control-panel/).
