---
permalink: create-custom-intelligence-dashboards
audit_date: '2017-07-28'
title: Create custom intelligence dashboards
type: article
created_date: '2017-07-25'
created_by: Nate Archer
last_modified_date: '2017-07-25'
last_modified_by: Nate Archer
product: Rackspace Intelligence
product_url: rackspace-intelligence
---

Rackspace Intelligence custom dashboards enable you to get a better view of your infrastructure through customized graphs and alerts.

You can create multiple dashboards to address different needs. For example, if you need to understand how servers in an application are performing, create a dashboard with graphs and alerting information for the servers in that application. Alternatively, create a dashboard to monitor specific metrics for database and production servers. Custom dashboards use the same checks and metrics that are available in Rackspace Monitoring.

This following article provides instructions on how to create, access, and edit custom dashboards.

### Create a custom dashboard

1. Log in to the Cloud Control Panel.
2. In the top navigation bar, select **Servers** > **Rackspace Intelligence**.
3. At the top of the Rackspace Intelligence page, click **Dashboard**.
4. In the dashboard page, click **Custom**.
5. On the Create Your Custom Dashboard page, provide a descriptive name for your dashboard and a brief description of it.
6. In the **Start From** menu, choose whether your dashboard should include any monitoring widgets by default.
7. Click **Next step: Add widgets**.

### Add widgets to a custom dashboard

A widget is a component of a custom dashboard that is customized to show the monitoring metrics for the check types or entities (instance or device) that you select. Two kinds of widgets are available: performance graphs and monitoring alerts.

#### Add performance graphs

Performance graphs show the relationships among various check types and metrics for specific entities. For more information about check types, see [Check types reference](https://docs.rackspace.com/docs/rackspace-monitoring/v1/tech-ref-info/check-type-reference/). For more information about metrics, see the Metrics section of the [Rackspace Monitoring API reference](https://docs.rackspace.com/docs/rackspace-monitoring/v1/api-reference/metrics-operations/).

Use the following process to add a performance graph to your custom dashboard:

1. Under **Categories**, click **Performance Graphs**.

   Check types and metrics are based on the same check types and metrics in Rackspace Monitoring. Each check type contains its own set of metrics.

2. Click one of the following tabs:

   - **Explore a Metric**: Creates a performance graph that focuses on one check type and one metric. The graph compares that metric across multiple entities (or devices such as servers or databases).
   - **Explore an Entity**: Creates a performance graph with one entity and one check type. The graph examines multiple metrics for the selected entity.

3. Select the values for the graph or graphs from the list of options:

   - If you selected the **Explore a Metric** tab, select one check type, one metric, and the **Entities** that you want to monitor.

      Every entity that you select is placed on a single graph by default. If you want to create individual graphs for each entity, clear the **Single graph for all Entities (Recommended)** check box.

   - If you selected the **Explore an Entity** tab, select one entity, one check type, and the metrics that you want to measure.

   **Note:** All check types, excluding remote checks, require the Rackspace Monitoring agent to be installed on the chosen entity before metrics are measured.

4. Click **Generate Graphs**. A preview of the graph appears under the value selection table.
5. Set the x-axis of the graphs to visualize metrics for either a preset amount of time or a custom amount of time.

   - For a preset amount of time, select **Presets** and then select the amount of preset time that you want to visualize. You can chose any of the following time spans: 1 hour (**1 hr**) , 8 hours (**8 hr**), one day (**day**), one week (**wk**), or one month (**mo**).
   - For a custom amount of time, select **Custom**, and then select the specific date and time for which you want to visualize your metrics. After you select the time span, click **Apply**.

6. Enter a name for the widget.
7. To add the graph to the custom dashboard, click **Add Graph**. To add the graph to and immediately view it on the custom dashboard, click **Add and View Graph**.

#### Add monitoring alerts

Monitoring alerts show alerts generated by Rackspace Monitoring. The monitoring alert widget for custom dashboards displays more information about an alert than the default dashboard.

Use the following process to add a monitoring alert widget to your custom dashboard:

1. Under **Categories**, click **Monitoring Alerts**.
2. Select one of the following options:

   - **Open Alerts**: Shows a list of alerts that are open right now and need to be addressed urgently
   - **All Alerts**: (Last 7 Days) Shows a list of all alerts that triggered in the last 7 days

3. Click **Preview**. A preview of the widget appears under the selection table.
4. Enter a name for the widget.
5. To add the alert to the custom dashboard, click **Add Alert**. To add the alert to and immediately view it on the custom dashboard, click **Add and View Alert**.

### Access and edit a custom dashboard

After you have created a custom dashboard, you can access and edit the dashboard as follows:

1. In the Cloud Control Panel, select **Servers** > **Rackspace Intelligence**.
2. At the top of the Rackspace Intelligence page, click **Dashboard**.
3. On the dashboard page, click **Custom**.
4. Select the custom dashboard you want to view from the drop-down menu.
5. If you want to change to a custom dashboard, click the **Actions** button at the top-right corner of the screen and select one of the following options:

  - **Rename dashboard**: Change the name of the dashboard.
  - **Add Widgets to Dashboard**: Add a new performance graph or monitoring alert to the dashboard.
  - **Delete Dashboard**: Deletes the selected dashboard. You can't recover a dashboard after it is deleted.
  - **Delete Dashboard's Widgets**: Deletes a widget from your custom dashboard.

### Export a graph as a CSV file

You can export any individual graph inside the widget of a custom dashboard as a CSV file. The CSV file contains the exact times and metrics visualized by the graph, allowing for a more comprehensive analysis of your infrastructure.

In the top-right corner of the graph that you want to export, click the gear icon and select Export as CSV.

The CSV file is saved to your local computer.
