---
permalink: business-email-101-an-8-step-guide-to-selecting-email-for-your-business
audit_date:
title: 'Business Email 101: An 8-Step Guide To Selecting Email For Your Business'
type: article
created_date: '2013-05-03'
created_by: Rackspace Support
last_modified_date: '2017-11-20'
last_modified_by: Stephanie Fillmon
---

For many companies today, email is the single most important
communications tool their employees use. In fact, the typical employee
spends 28% of his or her day doing something involving email — more time
than they will spend on the telephone, real-time communications and
social media combined.<sup>1</sup>

It’s no surprise, therefore, that most businesses now consider email a
mission-critical application. When an email system goes down, the costs
quickly add up: According to one estimate, just one hour per month of
unexpected downtime can cost a typical organization more than $250,000
a year.<sup>2</sup> That doesn’t include the possibility that a company could
lose a major sale or suffer long-term damage to its customer
relationships as a result of an extended email outage.

All of this explains why IT organizations have no room for error when it
comes to provisioning, managing and maintaining email systems. These are
expensive and time-consuming tasks for any IT organization, and they are
especially hard for small businesses with limited resources.

Fortunately, there’s an alternative:
[Hosted email solutions](https://www.rackspace.com/email-hosting/).

Hosted email providers offer top-flight technology and unbeatable
expertise; they maintain secure, reliable and scalable systems that can
grow with your business. Email service providers eliminate the need to
manage your own hardware or software, and they handle tasks like system
upgrades and data backups.

If you’re a large company with a dedicated IT department, email hosting
frees up money and resources to focus on more productive activities. If
you’re a small company, email hosting gives you all of the benefits of
enterprise-class email systems – at a fraction of the cost you’ll pay to
buy and manage those systems on your own.

The challenge is finding a
[hosted email solution](https://www.rackspace.com/email-hosting/) that fits your
business needs. Service providers offer a bewildering variety of email
platforms and options; different providers offer different combinations
of price, performance, support and service levels. Picking the right
email provider can be a daunting task, and your company can’t afford to
make the wrong choice.

This step-by-step guide will walk you through the process of picking the
best hosted email solution for your business. We’ll show you how to
create a set of technology and business requirements, explain the
difference between free and professional hosting solutions, and describe
some popular email hosting options. We’ll also show you how to pick a
hosting provider and give you some important tips for migrating to your
new provider’s hosted system.

Whether you’re thinking about moving away from an in-house email
platform or looking to upgrade from your current email provider, this
guide will provide everything you need to get started and to maximize
the return on investment from your new hosted solution.

### Step One: Hosted or In-House Email?

If your business is just getting started or you lack a dedicated IT
staff, the decision to use a hosted solution is easy. Even a basic
in-house email platform can be expensive given the cost of hardware,
software licenses, extra storage and network capacity, backups and labor
costs. And ensuring that your email system avoids unplanned downtime – a
key requirement for a mission- critical application – can be even more
costly.

If this describes your business, your decision-making process should
start with considering the costs and benefits of free versus
professional email hosting, and the differences between professional
hosted offerings. We discuss these issues beginning with Step Two
below.

For companies with an existing in-house email system – typically one
based on Microsoft Exchange – total cost of ownership (TCO) calculations
play a major role in your decision. Our sidebar, “The TCO Case For
Hosted Exchange,” offers an excellent introduction to this topic.

#### Five ‘red flag’ issues for in-house email performance.

Aside from TCO considerations, there are several red-flag issues that
indicate an existing in-house Exchange solution may be limiting your
business and imposing unnecessary costs:

1. **Are your employees complaining about a lack of storage?**

   Resource-constrained IT organizations often impose strict limits on the
   size of user Exchange mailboxes. These limits can inconvenience
   users; they may delete valuable messages to meet storage quotas, and the
   business suffers as a result. Hosted solutions address this problem
   with dynamic storage options that scale seamlessly to meet a
   company’s business needs.

2. **Do employees have trouble accessing the information they need?**

   Remote access to Exchange mailboxes, calendars, contacts and other
   applications can be complicated to manage – and to keep secure. As a
   result, many IT organizations limit off-site access to Exchange
   email. That’s a growing problem for today’s distributed, “always on”
   organizations.

3. **Are email outages killing your company’s productivity?**

   Companies with multiple locations often struggle with Exchange outages
   that create ripple effects elsewhere. Those with single locations don’t
   fare any better; in these situations, a single server outage can
   basically shut down the entire business until it’s fixed. Either
   way, unplanned email downtime is a nightmare for IT organizations – and
   a major drain on a company’s bottom line.

4. **Is your email infrastructure keeping up with mobile tech?**

   More employees than ever need access to their email, calendars and
   contacts over smartphones and tablets. Unfortunately, IT organizations
   often find it hard to keep up with the mobile-tech explosion; synching
   messages and data requires additional servers (and server licenses)
   that take time and effort to implement.

5. **Has your company suffered an email backup disaster?**

   A single failed backup can cripple a company’s ability to recover from an
   unexpected outage or business interruption. In addition, some companies
   rely on regular, robust email archiving to help them meet regulatory
   compliance and legal liability requirements. For many IT
   organizations, the cost and complexity of these tasks is increasing
   rapidly, and that creates a new source of business risk.

All of these problems can impose major, and completely avoidable,
business costs. The solution – moving to a quality hosted email service
– can help reduce your risk, improve productivity and free your IT staff
to focus on more important tasks that add lasting business value.

### Step Two: Free or Professional Email Hosting?

For many business owners, and especially cost-conscious small business owners,
[free email services](/support/how-to/the-real-costs-of-free-email-services-for-small-businesses)
can be a powerful draw. These services offer a number of selling points,
including fast account setup, convenient web-based interfaces and a
basic selection of easy-to-use features.

Free email services are certainly popular, and they offer enough options
to satisfy the majority of consumer users. But are they truly a good
value for businesses? Consider a few of the characteristics that define
the vast majority of free service providers:

- Calendar, task and contact management tools offer limited functionality and
interoperability.
- Limited and inconsistent spam filtering and malware protection.
- A lack of robust, cross-platform mobile data synching – a vital feature for
sales professionals and remote workers.
- Customer support capabilities may be limited to self-service message boards,
with no email or phone support.
- Privacy and security measures are geared towards casual consumer users – not
business users charged with protecting proprietary data and communications.
- No service-level agreements or system uptime guarantees.

There’s also an underlying issue for businesses that rely on free email
services: the service provider’s business model. In most cases, these
providers treat their email offering as a platform for marketing other
services (such as domain names) or for serving ads. Performance,
reliability, security and support aren’t priorities because the service
provider simply has no incentive for investing in these areas.

All of these concerns should play an important role when business users
compare the true costs of a “free” email service against the cost of
partnering with a professional hosted email service provider. As we will
discuss below, professional providers succeed or fail based entirely
upon their ability to deliver business-class tools, capabilities,
service and support. These providers invest heavily in maintaining and
upgrading their hosted email solutions; they provide mission-critical
business services, and their IT infrastructures reflect this fact.

### Step Three: Define Your Technology and Business Requirements

Advance planning is the key to any successful IT initiative, and an
email migration initiative is no exception. This planning process should
begin with an evaluation of your infrastructure, performance, security
and reliability requirements, including:

- **Systems integration**: Which systems and processes depend on email to
function properly? This includes CRM, ERP and other enterprise software systems,
but a migration may also impact things like marketing email campaigns, web site
forms and other hard-to-see components.
- **Security and compliance requirements**: Is your business subject to
compliance requirements that may dictate the need for a dedicated email hosting
solution? Does your executive management have expectations regarding data control
and security? These questions impact both your choice of a provider and your
choice of an email hosting option.
- **Service-level requirements**: Every company would love to have a
“gold plated” SLA for every hosted service. The reality is that there’s always
a trade-off between service levels and cost, and your IT organization should
think carefully about this trade-off before it settles on specific SLA
requirements.

It’s a mistake, however, to limit your requirements process to the IT
organization. Email is a critical application; employees spend a great
deal of time working with it, and even minor changes can disrupt your
business. You can avoid a lot of conflict and confusion by anticipating
these issues:

- **Identify key business stakeholders**: Sales, customer service and other
departments are especially dependent on email as a business tool. Bring these
groups into the conversation as soon as possible, and ask them to nominate
“power users” who can work with your IT team to define a set of working
requirements.
- **Collect relevant data**: Your current system analytics and logs hold a
wealth of data about how your business currently uses email. This data can, for
example, help you define requirements for attachment size limits and inbox
storage.
- **Look at your current functionality**: Which mobile platforms do your
employees use today? How do they use things like shared calendars, task
management systems and contact lists? This feedback will create a baseline for
the functionality you require from a hosted email solution.
- **Plan ahead for future functionality**: Talk to your stakeholders and power
users: What do they like about the current system, and what bothers them? Are
there new features that would make them more productive? Will those features
serve the business? How will growth affect your email needs, and is it possible
you’ll face unexpected growth.

### Step Four: Pick an Email Hosting Option

Business-grade email hosting providers also offer a wider range of
hosting options than
[free, consumer-focused email providers](/support/how-to/the-real-costs-of-free-email-services-for-small-businesses).
These options fall into three main categories, each of which offers a
unique mix of capabilities and business benefits.

**Webmail services**

These services are based on a familiar,
easy-to-use web interface, but they are far more powerful, reliable and
robust than free webmail services. They are usually the least expensive
hosted email option, and they are extremely quick and easy to setup. At
the same time, they still include a complete set of collaboration tools
(such as shared calendars), support for a wide range of mobile devices,
and other important features.

[Professional-grade webmail](https://www.rackspace.com/email-hosting/webmail/)
services are a great option for smaller, cost-conscious businesses that want
to get up and running as quickly as possible.

**Microsoft Exchange-based services**

[Microsoft Exchange](https://www.rackspace.com/email-hosting/hosted-exchange/) is
the most popular and feature-rich enterprise email platform on the
market today. Fortunately, businesses that have standardized on Exchange
(and the Microsoft Outlook desktop client) can also take advantage of
email hosting options.

In a hosted environment, a business no longer has to worry about
managing and maintaining its own Exchange servers – the provider takes
full responsibility for these tasks. Users get to work in the familiar,
feature rich Exchange/Outlook environment; they also get access to
powerful web-based and mobile messaging and collaboration tools.

Hosted Exchange services usually come in two flavors:
[shared](https://www.rackspace.com/email-hosting/hosted-exchange/) and
[dedicated](https://www.rackspace.com/managed_hosting/services/dedicated_exchange/)
hosting. Both offer the same level of security, performance and
reliability, but dedicated servers support a wider range of custom
options at a slightly higher monthly cost. (See below for a discussion
of how to choose between shared and dedicated hosting options.)

[Exchange hosting](https://www.rackspace.com/email-hosting/hosted-exchange/) is
an ideal choice for companies that want to migrate to an email service
provider without giving up their existing Microsoft applications, and
they are also a good choice for growing businesses that need a wider
range of collaboration and messaging tools than a webmail service can
provide.

**Hybrid hosted email services**

Webmail and hosted Exchange services don’t have to be mutually exclusive
options!
[Hybrid email services](https://www.rackspace.com/email-hosting/webmail-exchange-hybrid/)
allow a business to provision a mixture of webmail and hosted Exchange
accounts; both platforms allow seamless viewing and sharing of
calendars, contacts and other business data.

A hybrid solution is a good choice for cost-conscious businesses where
some employees require a full-featured Microsoft Exchange solution, and
other employees require the more selective capabilities of a webmail
account. A business might, for example, provision hosted Exchange
accounts for its executive management and sales team, while using less
expensive webmail accounts for its customer service reps.

### Step Five: Do You Need Dedicated Exchange?

If your business decides to use a hosted Microsoft Exchange solution,
you have another very important choice to make: whether to invest in a
[dedicated Exchange](https://www.rackspace.com/managed_hosting/services/dedicated_exchange/)
option.

What’s the difference between the standard hosted Exchange and dedicated
Exchange?

- A [hosted Exchange solution](https://www.rackspace.com/email-hosting/hosted-exchange/)
is a multi-tenant configuration, using a physical server shared with other users.
This option is simple to use and less expensive; it provides limited control
over Exchange’s application-level features without sacrificing security, privacy,
reliability or performance.
- A [dedicated Exchange solution](https://www.rackspace.com/managed_hosting/services/dedicated_exchange/)
is a single-tenant configuration, using dedicated physical servers that your
hosting provider maintains. It is a more expensive option, but it gives
businesses the ability to configure and customize their Exchange environments.

Here are some questions to help you decide which option is the best one
for your business:

1. **How much control does your business need over its Exchange settings and
policies?**

   A dedicated Exchange solution allows you to customize things like mailbox
   size, message size limit, deleted item and deleted mailbox retention, email
   filtering rules and backup. A dedicated server also gives you greater
   control over upgrade and service-pack installation planning. If your
   needs differ from a provider’s standard options in these and other
   areas, dedicated Exchange is a good choice.

2. **Do you need complete control over security?**

   A good provider’s multi-tenant Exchange security is very strong and
   perfectly adequate for most businesses. Some, however, require more
   control over specific security settings, or they may require
   separate servers – for example, due to regulatory compliance
   requirements. If these concerns apply to your business, it should
   consider dedicated Exchange.

3. **Do you need Active Directory (single sign-on) integration?**

   Hosted Exchange offers same sign-on capabilities to deliver a seamless
   login experience to users and simple user management for admins. For
   true single sign-on capability and
   [Active Directory integration](https://www.rackspace.com/blog/email-management-made-simple/),
   Dedicated Exchange is most appropriate.

4. **Is your company positioned for rapid growth?**

   Multi-tenant Exchange solutions are actually better options for rapid or
   unexpected growth, since they scale easily without forcing you to plan
   ahead or redesign your email solution.

5. **Does your business use SMTP relaying for things like marketing email
traffic?**

   You’ll need a dedicated Exchange environment to support relaying, since
   the spam filtering rules in multi-tenant environments don’t allow it.

6. **Do you have custom Disaster Recovery needs?**

   If your downtime and data-recovery expectations differ from those
   defined by a provider’s multi-tenant Exchange offering, then you may
   require a dedicated Exchange solution.

### Step Six: Take a Closer Look at Your Provider Options

We already discussed some of the “must have” features every
business-class hosted email provider should offer. In addition, your
final choice will depend upon the provider’s ability to offer the
appropriate hosting solution – webmail, Exchange or hybrid, and
multi-tenant or dedicated Exchange – for your business.

Once these requirements are met, you can ask another – and somewhat
tougher – set of questions to learn more about a potential provider. The
answers you get to these questions will go a long way towards separating
your top-tier provider options from the rest of the pack.

1. **Is your provider here for the long haul?**

   It’s surprising how many businesses neglect to ask this fundamental
   question. Look at the provider’s history and successful track record as
   an email provider. Check out the provider’s customers, leadership
   team and investors, and look at what the media has to say about the
   provider and its reputation.

2. **Can the provider prove its ability to scale and grow with your business?**

   Anyone can tell you that their email offerings are scalable. Ask them
   to prove it by explaining why their infrastructure is scalable – and
   ask for customer references that confirm these capabilities.

3. **Are the provider’s archiving solutions easy to manage?**

   [Archiving, discovery and recovery tools](https://www.rackspace.com/email-hosting/archiving-backup/)
   are an important litmus test for an email provider. Ask a potential
   provider to walk you through their policies, capabilities and
   procedures; pay particular attention to the vendor’s testing procedures
   for its archiving and backup systems.

4. **Can the provider document its security and privacy policies?**

   Data security standards such as PCI-DSS for e-commerce transactions and
   SSAE16 for data center security are an absolute necessity for most
   companies. Ask a provider to document its compliance with key
   standards – and always review a provider’s privacy policies.

5. **Does the provider use state-of-the-art malware and spam protection?**

   The good news is that most hosted email providers excel at stopping
   spam and malware before it reaches your employees’ inboxes. The bad news
   is that there are exceptions to the rule – and they can cost you dearly.

6. **Does the provider raise data ownership concerns?**

   Reputable providers always allow you to keep ownership of your business
   data. They also support standards that make it easy to download
   and/or export your email, contacts and other data. Don’t do business
   with providers that waffle on either of these two vital issues!

7. **Does the provider offer the right mix of online and mobile access options?**

   Define your requirements – web browser support and preferred mobile
   devices – and ensure that your provider supports these options using
   your chosen mix of webmail and Exchange-based  email tools.

8. **What does the provider really tell you in its SLA?**

   Simply promising 99.99% uptime (or any other uptime number) isn’t
   enough. You also need to know how the provider defines terms
   like “uptime” and “unplanned outage”; how the provider communicates with
   customers regarding outages; and how the provider compensates
   customers for outages.

9. **Does the provider offer migration support?**

   Whether you’re moving from an in-house system or another hosted email
   provider, the
   [email migration process](https://www.rackspace.com/email-hosting/migrations/)
   can be very complex and potentially risky. The right provider, with the
   right mix of migration resources, can minimize these risks and ensure
   that you get the ROI you expect from your new hosted email
   solution – from day one.

10. **How responsive is the provider’s customer service?**

   A provider’s
   [support options](https://www.rackspace.com/whyrackspace/support/) are
   only as good as the help you get using them. Does a provider guarantee
   response times on new support requests? Are there limits on after-hours
   phone support? What is a provider’s escalation process for
   high-priority requests? These are the details that can make or
   break a provider’s support capabilities.

### Step Seven: Compare Your Options — Make Your Final Choice

We’ve given you a lot of things to think about when you choose a hosted
email provider. To help you make a final decision, we have created a
comparison worksheet that covers the most important points of
comparison.

[Click here to download the Email Provider Comparison Worksheet](https://www.rackspace.com/apps/documents/Provider_Selection_Worksheet.pdf)

### Step Eight: Plan Your Migration Process

The actual process of migrating your email – whether it’s from an
existing provider or an in-house system – depends upon a large number of
variables. As we discussed above, a good service provider will offer the
right mix of tools, technical support resources and expert support to
walk your business through the technical details of a migration. The
data you gathered during your requirements process (see Step Three
above) will also help you plan a smooth and efficient migration.

At this point, however, there are a couple of additional tasks you’ll
want to add to your migration to-do list:

**Plan your training needs**

A hosted email solution will lighten the load on your IT organization, but
it may still require training. Your IT staff may, for example, need to get up
to speed on a provider’s
[management control panel](https://www.rackspace.com/apps/control_panel/), and
there may be additional training issues associated with a
customized, dedicated Exchange environment.

**Consider your end users’ training needs**

Moving from an in-house
Exchange environment to hosted Exchange will be transparent to most
users, but moving to a hosted webmail solution may require training on a
new user interface and tools. In addition, many hosted Exchange
environments introduce new tools and capabilities users didn’t have with
an in-house solution; here, too, it’s important to provide training on
these tools.

**Set a realistic migration timetable**

Work with your provider to set
a realistic schedule for provisioning and migrating to your new hosted
email environment. The exact timetable will depend upon the complexity
of the migration; third-party server integration, for example, can add
significant complexity to the process.

Also remember to involve your business users in the scheduling process.
Major business initiatives, such as marketing campaigns or a new web
site launch, should not overlap with a migration.

### Conclusion: Turning Hosted Email into a Competitive Advantage

There’s a lot to think about before you select a hosted email provider,
and there’s definitely a lot of planning involved. Some companies may
look at the steps required to complete this process and decide that it’s
more trouble than it’s worth.

Like any smart IT investment, however, it’s important to look at the
long-term benefits to your business. Hosted email solutions give IT
organizations two things they often lack: the time and resources to
focus on adding value to the business, instead of simply keeping the
lights on. Your employees will be more productive, your IT staff will be
more effective, and your business will gain an important competitive
advantage over firms that still sink resources into deploying and
maintaining in-house email systems.

That’s a big return on a relatively modest investment. And as we have
demonstrated here, the right planning and migration process can go a
long way towards making your hosted email investment even more likely to
pay quick dividends.

### Resources

<sup>1</sup> <https://www.ostermanresearch.com/ whitepapers/or_or1210c.pdf>

<sup>2</sup> <https://www.ostermanresearch.com/ whitepapers/or_or0509b.pdf>

### Additional information

[Rackspace Email:](https://www.rackspace.com/email-hosting/webmail/)
Business email hosting with email, calendars, contacts, and more on your
desktop

[Microsoft&reg; Exchange:](https://www.rackspace.com/apps/email_hosting/exchange_hosting/)
Advanced Outlook&reg; collaboration and optional push email for your
phone

[Exchange Hybrid:](https://www.rackspace.com/email-hosting/webmail-exchange-hybrid/)
Compared to using Hosted Exchange alone, a 50-user company can save 40%
by moving half their users from Exchange to Rackspace Email.

[Rackspace Email Archiving:](https://www.rackspace.com/email-hosting/archiving-backup/)
Email retention and storage service allows you to restore lost email,
take advantage of search tools, and protect vital email — without extra
software or expensive hardware.
